package com.demo;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;

import javax.swing.JPanel;

import org.jfree.chart.ChartPanel;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.plot.PiePlot;
import org.jfree.chart.ChartFactory;
import org.jfree.chart.title.TextTitle;
import org.jfree.chart.StandardChartTheme;

import org.jfree.ui.RectangleEdge;
import org.jfree.ui.RectangleInsets;
import org.jfree.ui.ApplicationFrame;
import org.jfree.ui.RefineryUtilities;
import org.jfree.ui.HorizontalAlignment;

import org.jfree.data.general.PieDataset;

public class PieChartDemo extends ApplicationFrame
{

	private static final long serialVersionUID = 1L;

	private JFreeChart  chart   = null;
	private PieDataset  dataset = null;
	
    static {
        // set a theme using the new shadow generator feature available in
        // 1.0.14 - for backwards compatibility it is not enabled by default
        ChartFactory.setChartTheme(new StandardChartTheme("JFree/Shadow", true));
    }

    public PieChartDemo(String title) {
        super(title);
        setContentPane(createChartPanel());
    }
    public JPanel createChartPanel() 
    {
    	dataset = Dataset.createPieDataset(Dataset.EXPENSES_05);
        chart = createChart(dataset);
        chart.setPadding(new RectangleInsets(4, 8, 2, 2));
        
        ChartPanel panel = new ChartPanel(chart);
        panel.setFillZoomRectangle(true);
        panel.setMouseWheelEnabled(true);
        panel.setPreferredSize(new Dimension(600, 400));
        return panel;
    }

    private JFreeChart createChart(PieDataset dataset)
    {
        JFreeChart chart = ChartFactory.createPieChart(
            "Семейные расходы",  // chart title
            dataset,             // data
            false,               // no legend
            true,                // tooltips
            false                // no URL generation
        );

        // Определение фона графического изображения
        chart.setBackgroundPaint(new Color(232, 232, 255));
        
        // Определение заголовка
        TextTitle title = chart.getTitle();
        title.setHorizontalAlignment(HorizontalAlignment.LEFT);
        title.setPaint(Color.DARK_GRAY);
        title.setFont(new Font("Arial", Font.BOLD, 26));

        // Определение подзаголовка
        TextTitle subtitle = new TextTitle("Семейные расходы за текущий месяц", 
                             new Font("Courier New", Font.PLAIN, 12));
        subtitle.setPaint(Color.DARK_GRAY);
        subtitle.setPosition(RectangleEdge.BOTTOM);
        subtitle.setHorizontalAlignment(HorizontalAlignment.RIGHT);
        chart.addSubtitle(subtitle);

        PiePlot plot = (PiePlot) chart.getPlot();
        // Фон
        plot.setBackgroundPaint(null);
        plot.setInteriorGap(0.04);
        // Обрамляющая граница
        plot.setOutlineVisible(false);
        // Выделение разделителей секций
        plot.setBaseSectionOutlinePaint(Color.WHITE);
        plot.setSectionOutlinesVisible(true);
        plot.setBaseSectionOutlineStroke(new BasicStroke(2.0f));

        // Настройка меток названий секций
        plot.setLabelFont(new Font("Courier New", Font.BOLD, 20));
        plot.setLabelLinkPaint(Color.WHITE);
        plot.setLabelLinkStroke(new BasicStroke(2.0f));
        plot.setLabelOutlineStroke(null);
        plot.setLabelPaint(Color.DARK_GRAY);
        plot.setLabelBackgroundPaint(null);
        return chart;
    }

    public static void main(String[] args)
    {
        PieChartDemo demo = new PieChartDemo("JFreeChart: Pie Chart");
        demo.pack();
        RefineryUtilities.centerFrameOnScreen(demo);
        demo.setVisible(true);
    }
}
